//
//  ViewController.swift
//  TicTacToe2020
//
//  Created by Andres Käver on 30.03.2020.
//  Copyright © 2020 Andres Käver. All rights reserved.
//

import UIKit

class ViewController: UIViewController {
    
    var game: GameBrain = GameBrain()
    var tileLabelChoices = ["❌","⭕️"]
    
    @IBOutlet var gameButtons: [UIButton]!
    @IBOutlet weak var labelNextMoveBy: UILabel!
    
    @IBAction func buttonStartGameTouchUpInside(_ sender: UIButton) {
        game.reset()
        updateUI()
    }
    
    @IBAction func buttonGameTouchUpInside(_ sender: UIButton) {
        let (col, row) = getCoords(tag: sender.tag)
        game.move(columnNo: col, rowNo: row)
        updateUI()
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        updateUI()
    }

    func updateUI(){
        for gameBtn in gameButtons {
            let (col, row) = getCoords(tag: gameBtn.tag)
            updateUI(button: gameBtn, tile: game.getTile(columnNo: col, rowNo: row))
        }
        
        labelNextMoveBy.text = game.nextMoveByCross ? tileLabelChoices[0] : tileLabelChoices[1]
        
    }
    
    func updateUI(button: UIButton, tile: Tile?){
        if let gameTile = tile {
            button.setTitle(gameTile.isCross ? tileLabelChoices[0] : tileLabelChoices[1], for: UIControl.State.normal)
        } else {
            button.setTitle("", for: UIControl.State.normal)
        }
    }
    
    func getCoords(tag: Int) -> (col: Int, row: Int) {
        let row = tag / 3
        let col = tag - row * 3
        return (col, row)
    }

}

